<?php 
  require "php/gopher.inc";
  start_page();
?>
<!-- START OF PAGE CONTENT -->

<h1>The GopherPHP configuration file</h1>

<p>
  The structure of a GopherPHP site is defined in a simple <b>XML configuration file</b>.  This configuration file consists of three main sections, which may be listed in any order and must be wrapped in a top-level <code>&lt;gopher&gt;</code> element.  Details for each configuration section are given below.  You can find a complete <a href="#example">configuration file example</a> at the bottom of this page.
</p>

<h2 id="config">Global settings: <code>&lt;config&gt;</code></h2>

<p>
  The <code>&lt;config&gt;</code> section contains some basic configuration settings for the site, which are specified as individual XML elements (containing the respective option value as body text) and can be listed in any order.  The following configuration settings are currently available:
</p>

<table border="0" align="center">
  <tr>
    <td valign="top"><code>&lt;id&gt;</code></td>
    <td width="20"></td>
    <td valign="top">ID code for the Web site (used e.g. in cookie names)</td>
  </tr>
  <tr>
    <td valign="top"><code>&lt;css&gt;</code></td>
    <td width="20"></td>
    <td valign="top">CSS stylesheet &mdash; only a single URL is allowed here<br/>
      (usually a relative path to one of the top-level GOPHER stylesheets)</td>
  </tr>
  <tr>
    <td valign="top"><code>&lt;name&gt;</code></td>
    <td width="20"></td>
    <td valign="top">Name of the Web site<br/>
      (used as HTML page title and site banner in the default page header)</td>
  </tr>
</table>

<h2 id="site">Site navigation: <code>&lt;site&gt;</code></h2>

<p>
  The <code>&lt;site&gt;</code> section describes the structure of a GopherPHP site.  It is used to generate the automatic navigation bar and (optionally) a complete site map.  All pages of the site must be listed here.  They are collected into <strong>page groups</strong>, which correspond to entries in the top row of the navigation bar.  The individual pages belonging to the currently active group are shown in the bottom row of the navigation bar.  Each page group is described by a <code>&lt;page&gt;</code> element as shown in the following example.
</p>
<pre>
&lt;group name=&quot;Documentation&quot; root=&quot;documentation.php&quot;&gt;
    &lt;page file=&quot;documentation.php&quot; name=&quot;User Manuals&quot;/&gt;
    &lt;page file=&quot;doc_faq.php&quot; name=&quot;FAQ&quot;/&gt;
    &lt;link url=&quot;http://wiki.myproject.org/&quot; name=&quot;Project Wiki&quot;/&gt;
&lt;/group&gt;
</pre>
<p>
  The group <code>name</code> is shown in the top row of the navigation bar.  It links to the specified <code>root</code> page, which must be one of the pages listed in this group.  Each individual page is described by an empty <code>&lt;page&gt;</code> element with attributes <code>file</code> (the filename of the Web page) and <code>name</code> (the page name shown in the bottom row of the navigation bar when the group is active).  In the navigation bar, groups and pages are listed in the same order as given in the configuration file.  Groups can also contain external links, which are included in the navigation bar and are specified by empty <code>&lt;link&gt;</code> elements with attributes <code>url</code> and <code>name</code>.  Empty groups (<code>&lt;group/&gt;</code>) can be used as “spacers” to adjust the layout of the navigation bar.
</p>

<p>
  <b>NB:</b> All pages of a GopherPHP Web site have to be <strong>in the same directory</strong>! In particular, the <code>file</code> and <code>root</code> attributes must be plain filenames without subdirectories.  It is probably a good idea to use a common filename prefix for all pages in a group, but this is not enforced by GopherPHP.  The sample configuration file below uses “short names” without prefix for some important pages such as <code>copyright.php</code> or <code>download.php</code>.
</p>


<h2 id="options">User display preferences: <code>&lt;options&gt;</code></h2>

<p>
  The <code>&lt;options&gt;</code> section enables users to set display preferences for this site (provided that cookies have been enabled).  Usually, the global preferences dialogue is enabled by setting <code>&lt;options button=&quot;yes&quot;&gt;</code>, and can be accessed by clicking on the <strong>preferences icon</strong> <img src="css/preferences.png" alt="Display Preferences Icon" border="0"/> in the top right corner of the navigation bar (see <a href="doc_specials.php">special features</a> if you prefer to offer a regular Web page for the preferences dialogue).
</p>

<p>
  Each preference item is described by a separate XML element, which contains <code>&lt;option&gt;</code> elements for the invidual options that can be selected.  The <code>name</code> attribute is shown in the preferences dialogue, while <code>value</code> specifies the internal value for this option.  One of the options can be marked as a default by setting <code>default="yes"</code>.  Currently, only two preference items are supported:
</p>
<ul>
  <li>
    <code>&lt;css&gt;</code> overrides the global <strong>CSS stylesheet</strong> defined in the <code>&lt;config&gt;</code> section. Values are relative or absolute URLs (usually of the form <code>css/gopher_XXX.css</code> to select one of the standard GOPHER styles).
  </li>
  <li>
    <code>&lt;fontsize&gt;</code> can be used to adjust <strong>font sizes</strong> for this site, overriding the default GOPHER font size (<code>small</code>). Values are CSS <code>font-size</code> specifications; for better compatibility, it is recommended to use absolute font sizes such as <code>medium</code> or <code>x-small</code>.
  </li>
</ul>
<p>
   GopherPHP sites should offer both preference items whenever possible, so that users can choose their preferred display settings.  It is usually sufficient to copy the <code>&lt;options&gt;</code> entry from the configuration file example below.
</p>


<h1 id="example">Configuration file example</h1>

<pre>
&lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;
&lt;gopher_config&gt;
    &lt;!-- Global configuration settings --&gt;
    &lt;config&gt;
        &lt;id&gt;gopher_homepage&lt;/id&gt;
        &lt;css&gt;css/gopher_web_rgb.css&lt;/css&gt;
        &lt;name&gt;GopherPHP: A simple site framework for GOPHER&lt;/name&gt;
    &lt;/config&gt;
    &lt;!-- User display preferences: global icon enabled with button=&quot;yes&quot; --&gt;
    &lt;options button=&quot;yes&quot;&gt; 
        &lt;css&gt;
            &lt;option name=&quot;Web fonts, RGB colour scheme (default)&quot; value=&quot;css/gopher_web_rgb.css&quot; default=&quot;yes&quot;/&gt;
            &lt;option name=&quot;Web fonts, purple colour scheme&quot; value=&quot;css/gopher_web_purple.css&quot;/&gt;
            &lt;option name=&quot;Office fonts, RGB colour scheme&quot; value=&quot;css/gopher_office_rgb.css&quot;/&gt;
            &lt;option name=&quot;Office fonts, purple colour scheme&quot; value=&quot;css/gopher_office_purple.css&quot;/&gt;
            &lt;option name=&quot;Mac OS X fonts, RGB colour scheme&quot; value=&quot;css/gopher_mac_rgb.css&quot;/&gt;
            &lt;option name=&quot;Mac OS X fonts, purple colour scheme&quot; value=&quot;css/gopher_mac_purple.css&quot;/&gt;
        &lt;/css&gt;
        &lt;fontsize&gt;
            &lt;option name=&quot;tiny&quot; value=&quot;xx-small&quot;/&gt;
            &lt;option name=&quot;small&quot; value=&quot;x-small&quot;/&gt;
            &lt;option name=&quot;normal (default)&quot; value=&quot;small&quot; default=&quot;yes&quot;/&gt;
            &lt;option name=&quot;medium&quot; value=&quot;medium&quot;/&gt;
            &lt;option name=&quot;large&quot; value=&quot;large&quot;/&gt;
        &lt;/fontsize&gt;
    &lt;/options&gt;
    &lt;!-- Site navigation: sections and pages --&gt;
    &lt;site&gt;
        &lt;group name=&quot;Introduction&quot; root=&quot;index.php&quot;&gt;
            &lt;page file=&quot;index.php&quot; name=&quot;Welcome to GOPHER&quot;/&gt;
            &lt;page file=&quot;copyright.php&quot; name=&quot;Author &amp;amp; Copyright&quot;/&gt;
            &lt;link url=&quot;http://purl.org/stefan.evert/GOPHER/&quot; name=&quot;GOPHER Homepage&quot;/&gt;
        &lt;/group&gt;
        &lt;group name=&quot;Documentation&quot; root=&quot;doc_page_skeleton.php&quot;&gt;
            &lt;page file=&quot;doc_page_skeleton.php&quot; name=&quot;Page skeleton&quot;/&gt;
            &lt;page file=&quot;doc_config_file.php&quot; name=&quot;Configuration files&quot;/&gt;
            &lt;page file=&quot;doc_headers_and_footers.php&quot; name=&quot;Header &amp;amp; Footers&quot;/&gt;
            &lt;page file=&quot;doc_specials.php&quot; name=&quot;Special features&quot;/&gt;
            &lt;page file=&quot;doc_gopher.php&quot; name=&quot;GOPHER layout&quot;/&gt;
        &lt;/group&gt;
        &lt;group name=&quot;Download&quot; root=&quot;download.php&quot;&gt;
            &lt;page file=&quot;download.php&quot; name=&quot;Download GOPHER&quot;/&gt;
            &lt;page file=&quot;install.php&quot; name=&quot;Installation instructions&quot;/&gt;
        &lt;/group&gt;
        &lt;group/&gt; &lt;!-- empty groups are used as spacers --&gt;
        &lt;group/&gt;
    &lt;/site&gt;
&lt;/gopher_config&gt;
</pre>

<!-- END OF PAGE CONTENT -->
<?php
  end_page();
?>

