<?php 
  require "php/gopher.inc";
  start_page();
?>
<!-- START OF PAGE CONTENT -->
  <p class="navigation">
    <a href="#formatting">Text formatting</a> &ndash;
    <a href="#sections">Page structure</a>
  </p>

  <h1>The GOPHER layout</h1>

  <p>
    This page describes the pre-defined CSS styles of GOPHER.  It serves both as a layout example and as documentation for non-standard elements and CSS classes.
  </p>

  <h1 id="formatting">Text formatting &amp; colour schemes</a></h1>
  <p class="backlink"><a href="#top">back to top</a></p>

  <p>
    Web page authors can select one of the pre-defined <strong>font sets</strong> and <strong>colour schemes</strong> by linking the appropriate top-level CSS stylesheet in the HTML header (e.g. <code>css/gopher_web_rgb.css</code> for standard Web fonts and the RGB colour scheme).  With the GopherPHP framework, the default stylesheet is specified in the <a href="doc_config_file.php">XML configuration file</a> and users can be allowed to select other stylesheets and font sizes (see <a href="doc_config_file.php#options">display preferences</a>).
  </p>

  <div class="figure-right" style="width:200px;">
    <img src="data/gopher.jpg" width="200"/>
    <p class="caption">
      Fig. 1: Richardson's Ground Squirrel, also known as <b>gopher</b>. Photograph &copy; <a href="http://martybugs.net/gallery" target="_blank">Martin Pot</a> (<a href="http://en.wikipedia.org/wiki/Image:Gopher.jpg" target="_blank">licensing information</a>).
    </p>
  </div>

  <p>
    Each <strong>font set</strong> specifies a set of matching sans-serif, <span class="serif">serif</span> and <code>monospace</code> fonts, including some size adjustments and multiple fallback fonts.
    <ul>
      <li>The default text font is sans-serif, which should look good in regular, <em>italic</em>, <strong>bold</strong>, and <em><strong>bold italic</strong></em> variants.</li>
      <li><span class="serif">Serif text (<code>class="serif"</code>) should also look good in regular, <em>italic</em>, <strong>bold</strong>, and <em><strong>bold italic</strong></em> variants.  Any HTML element can be formatted in serif font with the <code>class</code> attribute, e.g. <code>&lt;p class=&quot;serif&quot;&gt;serif text&lt;/p&gt;</code>.</span></li>
      <li>A matching <code>Typewriter font</code> is automatically used for <code>&lt;code&gt;</code> elements.</li>
      <li><span class="narrow">Narrow text (<code>class="narrow"</code>) allows you to squeeze more text in a single line, but is not guaranteed to have <em>italic</em> or <strong>bold</strong> variants.  A suitable narrow font may not always be available, causing the GOPHER style to fall back on a regular-width font.</span></li>
    </ul>
  </p>

  <p>
    A <strong>colour scheme</strong> defines matching colours for various page elements, including the banner, navigation bar and section headers.  <a href="">Hyperlinks</a> also match the selected colour scheme.  Use <code>&lt;a href=&quot;...&quot; target=&quot;_blank&quot; class=&quot;external&quot;&gt;</code> for <a href="" target="_blank" class="external">external links</a>, which open the new page in a separate window and display a small arrow next to the hyperlink (this feature is not supported by all Web browsers, though).  In order to match their original page content to the currently selected colour scheme, Web page authors can use pre-defined primary and secondary highlight colours for text and/or background (e.g. of table cells).  The following CSS classes are available for this purpose:
  </p>
  
  <table align="center">
    <tr>
      <td align="right"><em>primary:</em></td>
      <td width="10"></td>
      <td class="fg1">text (<code>class="fg1"</code>)</td>
      <td width="10"></td>
      <td class="bg1">background (<code>class="bg1"</code>)</td>
      <td width="10"></td>
      <td class="fg1 bg1">both (<code>class="fg1 bg1"</code>)</td>
      <td width="10"></td>
      <td class="inv1">inverse (<code>class="inv1"</code>)</td>
    </tr>
    <tr>
      <td align="right"><em>secondary:</em></td>
      <td width="10"></td>
      <td class="fg2">text (<code>class="fg2"</code>)</td>
      <td width="10"></td>
      <td class="bg2">background (<code>class="bg2"</code>)</td>
      <td width="10"></td>
      <td class="fg2 bg2">both (<code>class="fg2 bg2"</code>)</td>
      <td width="10"></td>
      <td class="inv2">inverse (<code>class="inv2"</code>)</td>
    </tr>
  </table>

  <p>
    <strong>Figures</strong> can be inserted in the left or right margin with <code>&lt;div class=&quot;figure-left&quot; style=&quot;width:...;&quot;&gt;</code> (or <code>figure-right</code>, respectively), as demonstrated by Figure 1.  It is important to specify the precise width of the figure in order to ensure correct layout.  Figure captions should be typeset with <code>&lt;p class=&quot;caption&quot;&gt;</code> within this <code>&lt;div&gt;</code>.
  </p>

  <p>
    The GOPHER styles also set up indentation and bullets for unordered lists (<code>&lt;ul&gt;</code>):
    <ul>
      <li>first item</li>
      <li>second item
        <ul>
          <li>with a sublist</li>
        </ul>
      </li>
      <li>third item</li>
    </ul>
    Spacing between list elements can be reduced with <code>class="compressed"</code>, e.g. for lists of names:
    <ul class="compressed">
      <li>Arthur Dent</li>
      <li>Ford Prefect</li>
      <li>Zaphod Beeblebrox</li>
      <li>Tricia McMillan</li>
    </ul>
    Pre-formatted text (<code>&lt;pre&gt;</code>) is typeset in an indented box with a coloured frame:
<pre>
foreach $x (1..9) {
    print "This is sample line $i\n";
}
</pre>
    Make sure that the closing tag (<code>&lt;/pre&gt;</code>) is not indented with blanks, otherwise there will be an empty line at the bottom of the box.
    Important text passages can be highlighted by typesetting them in a block element with <code>class="box"</code> (e.g. <code>&lt;div class=&quot;box&quot;&gt;</code>):
    <div class="box">
      <strong>This is a very important remark.</strong>
      <ul>
          <li>Highlighted boxes may also contain lists and any other structured layout!</li>
      </ul>
      Note that the last line of text should be immediately adjacent to the bottom border.
    </div>
  </p>

  <h1 id="sections">Page structure: sections &amp; subsections</a></h1>
  <p class="backlink"><a href="#top">back to top</a></p>

  <p>
    GOPHER pre-defines styles for section and subsection headers (<code>&lt;h1&gt;</code>, <code>&lt;h2&gt;</code> and <code>&lt;h3&gt;</code>).  You can add a link back to the top of the page by following the header immediately with
  <code>&lt;p class=&quot;backlink&quot;&gt;&lt;a href=&quot;#top&quot;&gt;back to top&lt;/a&gt;&lt;/p&gt;</code>
    The link should appear immediately below the coloured bar, in a small font and right-justified.  Make sure that an anchor named <code>top</code> is set somewhere near the top of the page.  Of course, you can use such paragraphs to display any other information as well (e.g. the copyright message in the default page footer).
  </p>
  
  <p>
    Section (and possibly subsection) headers should be labelled with IDs or named anchors for page-internal navigation.  A simple navigation bar (as seen at the top of this page) can be inserted with <code>&lt;p class=&quot;navigation&quot;&gt;</code> and <code>&amp;ndash;</code> separators between the links.
  </p>

  <h2>Subsection header (<code>&lt;h2&gt;</code>)</h2>
  <p>
    Section (<code>&lt;h1&gt;</code>) and subsection (<code>&lt;h2&gt;</code>) headers form the main divisions of a GOPHER page.  Subheadings within a thematically connected paragraph can be inserted with <code>&lt;h3&gt;</code> elements.
  </p>
  
  <h3>Subheading (<code>&lt;h3&gt;</code>)</h3>
  <p>
    Note that there is no coloured bar below a <code>&lt;h3&gt;</code>-level header. 
  </p>

  <h2>Subsection with backlink</h2>
  <p class="backlink"><a href="#top">back to top</a></p>
  <p>
    The position of the following paragraph is adjusted automatically for headers with backlinks.
  </p>

<!-- END OF PAGE CONTENT -->
<?php
  end_page();
?>

