<?php
/* paths to configuration files (hard-coded) */
$config_file = 'php/gopher_config.xml';
$page_header = 'php/page_header.php';
$page_footer = 'php/page_footer.php';

$GOPHER_VERSION = "1.1";

/* read XML configuration file and extract basic information */
if (!file_exists($config_file)) error_page("Can't find the configuration file “${config_file}”.");
$GOPHER_CONFIG = simplexml_load_file($config_file);
if (!$GOPHER_CONFIG) error_page("Syntax error in configuration file “${config_file}”.");

$SITE_ID = (string) $GOPHER_CONFIG->config->id;
if (!$SITE_ID) error_page("Syntax error in configuration file: missing site ID (//config/id).");
$GOPHER_PAGETITLE = htmlspecialchars($GOPHER_CONFIG->config->name);
if (!$GOPHER_PAGETITLE) error_page("Syntax error in configuration file: missing site name (//config/name).");
$GOPHER_CSS = htmlspecialchars($GOPHER_CONFIG->config->css);
if (!$GOPHER_CSS) error_page("Syntax error in configuration file: missing CSS link (//config/css).");
$GOPHER_STYLES = "";

/* process user configuration options (stored in cookies, can be set with a POST request) */
$option_css = $_POST['option_css'];
if (! $option_css)
  $option_css = $_COOKIE[$SITE_ID."_css"];
if ($option_css && check_option_value($option_css, $GOPHER_CONFIG->options->css)) {
  if ($_POST['option_css'])
    setcookie($SITE_ID."_css", $option_css, time()+7*24*60*60); /* set cookie only if option has been changed */
  $GOPHER_CSS = $option_css;  
} 
$option_fontsize = $_POST['option_fontsize'];
if (! $option_fontsize)
  $option_fontsize = $_COOKIE[$SITE_ID."_fontsize"];
if ($option_fontsize && check_option_value($option_fontsize, $GOPHER_CONFIG->options->fontsize)) {
  if ($_POST['option_fontsize'])
    setcookie($SITE_ID."_fontsize", $option_fontsize, time()+7*24*60*60); /* set only if option has been changed */
  $GOPHER_STYLES .= "body { font-size:".htmlspecialchars($option_fontsize).";}\n";  
}

function navigation_bar ($config, $current_page) {
  $current_page = basename($current_page);
  $groups = $config->xpath("site/group");
  if (!$groups) error_page("Syntax error in configuration file: no page groups found (//site/group).");
  ?>
<div class="navigation">
<table>
<tr class="sitenav">
<td></td>
  <?php
  $current_group = FALSE; 
  foreach ($groups as $group) {
    $group_name = htmlspecialchars($group['name']);
    $start_page = htmlspecialchars($group['root']);
    $pages = $group->children();
    if (count($pages) == 0) {
      ?>
<td class="space"></td> 
      <?php
    }
    else {
      $is_active = FALSE;
      foreach ($pages as $page) {
        if ($page['file'] == $current_page) $is_active = TRUE;
      }
      if ($is_active) {
        $current_group = $group;
        ?>
<td class="current"><?=$group_name?></td>
        <?php
      }
      else {
        ?>
<td><a href="<?=$start_page?>"><?=$group_name?></a></td>
        <?php
      }
    }
  }
  ?>
<td style="padding-right:10px; padding-left:2px; text-align:right; vertical-align:middle;">
  <?php
  if ($config->options['button'] == "yes") {
    ?>
    <a href="<?=$current_page?>?config=yes"><img src="css/preferences.png" alt="Change Display Preferences" border="0"/></a>
    <?php
  }
  ?>
</td>
</tr>
  <?php
  if (!$current_group) error_page("Current page not listed in site configuration.");
  ?>
<tr class="subnav">
<td class="php" colspan="<?=count($groups)+2?>">
  <?php
  $first_item = TRUE;
  foreach ($current_group->children() as $page) {
    if ($first_item) $first_item = FALSE; else echo ' &mdash; ';
    if ($page->getName() == "link") {
      $link_url = htmlspecialchars($page['url']);
      $link_name = htmlspecialchars($page['name']);
      echo '<a href="'.$link_url.'" class="external" target="_blank">'.$link_name.'</a>';
    }
    else {
      $page_name = htmlspecialchars($page['name']);
      $page_url = htmlspecialchars($page['file']);
      if ($page['file'] == $current_page) {
        echo '<span class="current">'.$page_name.'</span>';
      }
      else {
        echo '<a href="'.$page_url.'">'.$page_name.'</a>';
      }
    }
  }
  ?>
</td>
</tr>
</table>
</div>
  <?php
}

function start_page () {
  global $page_header, $page_footer, $GOPHER_CONFIG;
  global $GOPHER_PAGETITLE, $GOPHER_CSS, $GOPHER_STYLES;
  if (!file_exists($page_header)) error_page("Missing page header template “${page_header}”.");
  if (!file_exists($page_footer)) error_page("Missing page footer template “${page_footer}”.");
  include $page_header;
  if ($_GET['config']) {
    ?>
<h1>Display preferences</h1>
<div align="center" style="margin-top:1em;">
    <?php display_preferences(); ?>
</div>
    <?php
    end_page();
    exit;
  }
  else {
    navigation_bar($GOPHER_CONFIG, $_SERVER['PHP_SELF']);
  }
}

function end_page () {
  global $page_footer;
  global $GOPHER_PAGETITLE, $GOPHER_CSS;
  include $page_footer;
}

function error_page ($message) { 
  if (!headers_sent()) {
    ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <title>GopherPHP: Error</title>
</head>
<body>
    <?php
  }
  ?>
  <h1 style="color: red;">GopherPHP: Internal Error</h1>
  <p style="font-size: 120%; font-weight: bold;"><?=htmlspecialchars($message)?></p>
</body>
</html>
  <?php
  exit;
}

function check_option_value ($value, $option_element) {
  foreach ($option_element->children() as $option) {
    if ($option['value'] == $value) return TRUE;
  }
  return FALSE;
}

function display_preferences () {
  global $GOPHER_CONFIG, $option_css, $option_fontsize;
  ?>
<table border="0">
<tr>
<td align="left" valign="bottom">
<form action="<?=htmlspecialchars($_SERVER['PHP_SELF'])?>" method="post">
<ul>
  <?php
  $config_css = $GOPHER_CONFIG->options->css;
  if ($config_css)
    preferences_entry("Display style", "css", $config_css, $option_css);
  $config_fontsize = $GOPHER_CONFIG->options->fontsize;
  if ($config_fontsize)
    preferences_entry("Font size", "fontsize", $config_fontsize, $option_fontsize);
  ?>
</ul>
<input type="submit" value="Save Changes">
</form>
</td>
<td width="20"></td>
<td align="right" valign="bottom">
<form action="<?=htmlspecialchars($_SERVER['PHP_SELF'])?>" method="get">
<input type="submit" value="Cancel">
</form>
</td>
</tr>
</table>
  <?php
}

function preferences_entry ($name, $code, $option_element, $selected) {
  $use_default = (check_option_value($selected, $option_element)) ? FALSE : TRUE;
  ?>
<li><b><?=htmlspecialchars($name)?>:</b>
<select name="option_<?=htmlspecialchars($code)?>" size="1">
  <?php
  foreach ($option_element->children() as $option) {
    $name = htmlspecialchars($option['name']);
    $value = htmlspecialchars($option['value']);
    if ($use_default)
      $is_selected = ($option['default']) ? $option['default'] : FALSE;
    else
      $is_selected = ($option['value'] == $selected) ? TRUE : FALSE;
    echo "\t".'<option value="'.$value.'"';
    if ($is_selected) echo ' selected="selected"';
    echo '>'.$name."</option>\n";
  }
  ?>
</select>
</li>
  <?php
}

function show_sitemap () {
  global $GOPHER_CONFIG;
  ?>
<ul>
  <?php
  foreach ($GOPHER_CONFIG->xpath("site/group") as $group) {
    $group_name = htmlspecialchars($group['name']);
    $start_page = htmlspecialchars($group['root']);
    $pages = $group->children(); /* make sure we don't list empty groups used as spacers */
    if (count($pages) > 0) {
      ?>
<li>
<b><a href="<?=$start_page?>"><?=$group_name?></a></b>
<ul>
      <?php
      foreach ($pages as $page) {
        $page_name = htmlspecialchars($page['name']);
        if ($page->getName() == "link") {
          $link_url = htmlspecialchars($page['url']);        
          ?>
<li>
<a href="<?=$link_url?>" class="external" target="_blank"><?=$page_name?></a>
</li>
          <?php
        }
        else {
          $page_url = htmlspecialchars($page['file']);        
          ?>
<li>
<a href="<?=$page_url?>"><?=$page_name?></a>
</li>
          <?php
        }
      }
      ?>
</ul>
</li>
      <?php
    }
  }
  ?>
</ul>
  <?php
}

function gopher_copyright () {
  global $GOPHER_VERSION;
  ?>powered by <a href="http://purl.org/stefan.evert/GOPHER/" target="_blank">GopherPHP</a> version <?=$GOPHER_VERSION?> (&copy; 2008 by <a href="http://purl.org/stefan.evert/" target="_blank">Stefan Evert</a>)<?php
}

?>
